import sys
print(f"程序包含模板：{sys.modules}")
print(f"程序程序路径：{sys.path}")
print(f"程序运行平台：{sys.platform}")
print(f"程序默认编码：{sys.getdefaultencoding()}")

def get_information():
    return "ckh2.handsome.com"
